@@ -88,7 +88,8 @@
 #' @examples
 #' library(recipes)
 #' library(timetk)
-#' library(tidyverse)
+#' library(tibble)
+#' library(dplyr)
 #'
 #' # Sample Data
 #' dates_in_2017_tbl <- tibble(
@@ -174,14 +175,7 @@ prep.step_holiday_signature <- function(x, training, info = NULL, ...) {
 
     col_names <- recipes::recipes_eval_select(x$terms, data = training, info = info)
 
-    date_data <- info[info$variable %in% col_names, ]
-
-    if (any(!date_data$type %in% c("date", "datetime")))
-        rlang::abort(
-            paste0("All variables for `step_holiday_signature` should be either `Date` or",
-                   "`POSIXct` classes."
-            )
-        )
+    recipes::check_type(training[, col_names], types = c("date", "datetime"))
 
     # Prep Information
     proxy_signature <- tk_get_holiday_signature(
