@@ -11,11 +11,9 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 
-## ---- echo=FALSE--------------------------------------------------------------
-knitr::include_graphics("timetk_version_2.jpg")
-
 ## ----setup--------------------------------------------------------------------
-library(tidyverse)
+library(dplyr)
+library(ggplot2)
 library(lubridate)
 library(timetk)
 
